/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map.Entry;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.io.Writable;
import org.apache.hadoop.util.ReflectionUtils;


public class LyraMessageBundle implements Writable {
  public static final Log LOG = LogFactory.getLog(LyraMessageBundle.class);

  private List<LyraSyncMessage> bundle;
  
  public LyraMessageBundle() {
    bundle = new ArrayList<LyraSyncMessage>();
  }
  
  public LyraMessageBundle(List<LyraSyncMessage> b) {
    bundle = new ArrayList<LyraSyncMessage>(b);
  }
  
  public void addMessage(LyraSyncMessage message) {
      bundle.add(message);
  }

  public List<LyraSyncMessage> getMessages() {
    return bundle;
  }
  
  public void clear() {
    bundle.clear();
  }
  
  public int size() {
    return bundle.size();
  }
  
  public List<LyraMessageBundle> split(int n) {
    List<LyraMessageBundle> lists = new ArrayList<LyraMessageBundle>();
    int piece = bundle.size() / n;
    LyraMessageBundle b = null;
    int from = 0, to = 0;

    for (int i = 0; i < n - 1; i++) {
      from = to;
      to = from + piece;
      lists.add(new LyraMessageBundle(bundle.subList(from, to)));
    }
    from = to;
    to = bundle.size();
    lists.add(new LyraMessageBundle(bundle.subList(from, to)));

    return lists;
  }
  
  public boolean isEmpty() {
    return bundle.isEmpty();
  }
  
  @Override
  public void write(DataOutput out) throws IOException {
    if (LOG.isDebugEnabled()){
      LOG.info("******************* lyraMessageBundle Size: " + bundle.size() + "**********************");
    }
    out.writeInt(bundle.size());
    for (Writable msg : bundle) {
      msg.write(out);
    }
    if (LOG.isDebugEnabled()){
      org.apache.hadoop.io.DataOutputBuffer t = (org.apache.hadoop.io.DataOutputBuffer) out;
      LOG.info("******************* DataOutputBuffer length: " +  t.getLength() + "**********************");
    }
  }

  @Override
  @SuppressWarnings("unchecked")
  public void readFields(DataInput in) throws IOException {
    if (bundle == null)
      bundle = new LinkedList<LyraSyncMessage>();
    
    int size = in.readInt();
    for (int i = 0; i < size; i++) {
      LyraSyncMessage msg = new LyraSyncMessage();
      msg.readFields(in);
      bundle.add(msg);
    }
  }
  
  // general version code
  /*private LinkedList<Writable> bundle = new LinkedList<Writable>();
  private Class<? extends Writable> valueClass;
  
  public LyraMessageBundle(Class<? extends Writable> valueClass) {
    if (valueClass == null) { 
      throw new IllegalArgumentException("null valueClass"); 
    }    
    this.valueClass = valueClass;
  }
  
  public void addMessage(Writable message) {
      bundle.add(message);
  }

  public List<Writable> getMessages() {
    return bundle;
  }
  
  @Override
  public void write(DataOutput out) throws IOException {
    out.writeUTF(valueClass.getName());
    out.writeInt(bundle.size());
    for (Writable msg : bundle) {
      msg.write(out);
    }
  }

  @Override
  @SuppressWarnings("unchecked")
  public void readFields(DataInput in) throws IOException {
    if (bundle == null)
      bundle = new LinkedList<Writable>();
    
    String className = in.readUTF();
    int size = in.readInt();
    Class<Writable> clazz = null;
    
    try {
      clazz = (Class<Writable>) Class.forName(className);
    } catch (ClassNotFoundException e) {
      LOG.error("Class was not found.", e);
    }
    
    for (int i = 0; i < size; i++) {
      Writable msg = ReflectionUtils.newInstance(clazz, null);
      msg.readFields(in);
      bundle.add(msg);
    }
  }*/
}
