/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.io.DoubleWritable;
import org.apache.hadoop.io.LongWritable;
import org.apache.hadoop.io.Writable;
import org.apache.hadoop.util.ReflectionUtils;

public class LyraTestMessage implements Writable {
  private static final Log LOG = LogFactory.getLog(LyraTestMessage.class);

  public static Class<? extends Writable> VERTEX_ID_CLASS;
  public static Class<? extends Writable> VERTEX_VALUE_CLASS;
  
  private LongWritable id;
  private DoubleWritable value;
  
  public LyraTestMessage() {
    
  }
  
  public LyraTestMessage(LongWritable id, DoubleWritable value) {
    this.id = id;
    this.value = value;
  }
  
  @Override
  public void write(DataOutput out) throws IOException {
    id.write(out);
    value.write(out);
  }
  
  @Override
  public void readFields(DataInput in) throws IOException {
    id = new LongWritable();
    id.readFields(in);
    value = new DoubleWritable();
    value.readFields(in);
  }
  
  public DoubleWritable getValue() {
    return value;
  }
  
  public LongWritable getID() {
    return id;
  }
}
