/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map.Entry;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.io.Writable;
import org.apache.hadoop.util.ReflectionUtils;


public class LyraTestMessageBundle implements Writable {
  public static final Log LOG = LogFactory.getLog(LyraTestMessageBundle.class);

  private List<LyraTestMessage> bundle;
  
  public LyraTestMessageBundle() {
    bundle = new ArrayList<LyraTestMessage>();
  }
  
  public void addMessage(LyraTestMessage message) {
      bundle.add(message);
  }

  public List<LyraTestMessage> getMessages() {
    return bundle;
  }
  
  public void clear() {
    bundle.clear();
  }
  
  public boolean isEmpty() {
    return bundle.isEmpty();
  }
  
  @Override
  public void write(DataOutput out) throws IOException {
    out.writeInt(bundle.size());
    for (Writable msg : bundle) {
      msg.write(out);
    }
  }

  @Override
  @SuppressWarnings("unchecked")
  public void readFields(DataInput in) throws IOException {
    if (bundle == null)
      bundle = new LinkedList<LyraTestMessage>();
    
    int size = in.readInt();
    for (int i = 0; i < size; i++) {
      LyraTestMessage msg = new LyraTestMessage();
      msg.readFields(in);
      bundle.add(msg);
    }
  }
}
