/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp.message;

import java.lang.reflect.Array;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.io.Writable;
import org.apache.hadoop.util.ReflectionUtils;

public class LyraMessageManagerFactory {
  public static final String LYRA_MESSAGE_MANAGER_CLASS = "hama.lyra.messenger.class";

  /**
   * Returns a messenger via reflection based on what was configured.
   * 
   * @param conf
   * @return
   */
  @SuppressWarnings("unchecked")
  public static <M extends Writable> LyraMessageManager<M> getMessageManager(
      Configuration conf) throws ClassNotFoundException {
    return (LyraMessageManager<M>) ReflectionUtils.newInstance(conf
        .getClassByName(conf.get(LYRA_MESSAGE_MANAGER_CLASS,
            org.apache.hama.bsp.message.LyraMessageManagerImpl.class
                .getCanonicalName())), conf);
  }
  
  @SuppressWarnings("unchecked")
  public static <M extends Writable> LyraMessageManager<M>[] getMessageManagers(
      Configuration conf, int numberManagers) throws ClassNotFoundException {
    LyraMessageManager<M>[] managers = (LyraMessageManager<M>[]) Array.newInstance(
        conf.getClassByName(conf.get(LYRA_MESSAGE_MANAGER_CLASS,
            org.apache.hama.bsp.message.LyraMessageManagerImpl.class
                .getCanonicalName())), numberManagers);
    for (int i = 0; i < numberManagers; i++)
      managers[i] = LyraMessageManagerFactory.getMessageManager(conf);
    
    return managers;
  }

}
