/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.io.Writable;
import org.apache.hadoop.util.ReflectionUtils;

public class LyraRecoverMessageBundle<M extends Writable> implements Writable{
  public static final Log LOG = LogFactory.getLog(LyraRecoverMessageBundle.class);
  
  private List<M> bundle;

  public LyraRecoverMessageBundle() {
    bundle = new ArrayList<M>();
  }

  public LyraRecoverMessageBundle(List<M> b) {
    bundle = new ArrayList<M>(b);
  }

  public void addMessage(M message) {
    bundle.add(message);
  }

  public List<M> getMessages() {
    return bundle;
  }

  public void clear() {
    bundle.clear();
  }

  public int size() {
    return bundle.size();
  }

  public boolean isEmpty() {
    return bundle.isEmpty();
  }

  public void write(DataOutput out) throws IOException {
    if (LOG.isDebugEnabled()) {
      LOG.debug("******************* RecoverMessageBundle Size: " + bundle.size()
          + "**********************");
    }
    out.writeInt(bundle.size());
    String className = null;
    for (M msg : bundle) {
      if (className == null) {
        className = msg.getClass().getName();
        out.writeUTF(className);
      }
      msg.write(out);
    }
    if (LOG.isDebugEnabled()) {
      org.apache.hadoop.io.DataOutputBuffer t = (org.apache.hadoop.io.DataOutputBuffer) out;
      LOG.debug("******************* RecoverDataOutputBuffer length: "
          + t.getLength() + "**********************");
    }
  }

  @SuppressWarnings("unchecked")
  public void readFields(DataInput in) throws IOException {
    if (bundle == null)
      bundle = new LinkedList<M>();

    int size = in.readInt();
    String className = null;
    Class<M> clazz = null;
    M msg = null;
    for (int i = 0; i < size; i++) {
      if (className == null) {
        try {
          className = in.readUTF();
          clazz = (Class<M>) Class.forName(className);
        } catch (ClassNotFoundException e) {
          LOG.error("Class was not found.", e);
          System.exit(-1);
        }
      }
      msg = ReflectionUtils.newInstance(clazz, null);
      msg.readFields(in);
      bundle.add(msg);
    }
  }
}