/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.io.Writable;


public class LyraSyncBundle implements Writable {
  public static final Log LOG = LogFactory.getLog(LyraMessageBundle.class);

  @SuppressWarnings("rawtypes")
  private List<LyraSyncMessage> bundle;
  
  @SuppressWarnings("rawtypes")
  public LyraSyncBundle() {
    bundle = new ArrayList<LyraSyncMessage>();
  }
  
  @SuppressWarnings("rawtypes")
  public LyraSyncBundle(List<LyraSyncMessage> b) {
    bundle = new ArrayList<LyraSyncMessage>(b);
  }
  
  @SuppressWarnings("rawtypes")
  public void addMessage(LyraSyncMessage message) {
      bundle.add(message);
  }

  @SuppressWarnings("rawtypes")
  public List<LyraSyncMessage> getMessages() {
    return bundle;
  }
  
  public void clear() {
    bundle.clear();
  }
  
  public int size() {
    return bundle.size();
  }
  
  public List<LyraSyncBundle> split(int n) {
    List<LyraSyncBundle> lists = new ArrayList<LyraSyncBundle>();
    int piece = bundle.size() / n;
    int from = 0, to = 0;

    for (int i = 0; i < n - 1; i++) {
      from = to;
      to = from + piece;
      lists.add(new LyraSyncBundle(bundle.subList(from, to)));
    }
    from = to;
    to = bundle.size();
    lists.add(new LyraSyncBundle(bundle.subList(from, to)));

    return lists;
  }
  
  public boolean isEmpty() {
    return bundle.isEmpty();
  }
  
  @Override
  public void write(DataOutput out) throws IOException {
    if (LOG.isDebugEnabled()){
      LOG.debug("******************* lyraMessageBundle Size: " + bundle.size() + "**********************");
    }
    out.writeInt(bundle.size());
    for (Writable msg : bundle) {
      msg.write(out);
    }
    if (LOG.isDebugEnabled()){
      org.apache.hadoop.io.DataOutputBuffer t = (org.apache.hadoop.io.DataOutputBuffer) out;
      LOG.debug("******************* DataOutputBuffer length: " +  t.getLength() + "**********************");
    }
  }

  @Override
  @SuppressWarnings({ "rawtypes" })
  public void readFields(DataInput in) throws IOException {
    if (bundle == null)
      bundle = new LinkedList<LyraSyncMessage>();
    
    int size = in.readInt();
    for (int i = 0; i < size; i++) {
      LyraSyncMessage msg = new LyraSyncMessage();
      msg.readFields(in);
      bundle.add(msg);
    }
  }
}
