/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp.message;

import java.io.IOException;
import java.util.List;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.io.IntWritable;
import org.apache.hadoop.io.MapWritable;
import org.apache.hama.bsp.AbstractGlobalState;
import org.apache.hama.bsp.AbstractVertex;
import org.apache.hama.bsp.LyraMessageBundle;
import org.apache.hama.bsp.LyraMirrorMessage;
import org.apache.hama.bsp.LyraRecoverMessage;
import org.apache.hama.bsp.LyraRecoverMessageBundle;
import org.apache.hama.bsp.LyraSyncBundle;
import org.apache.hama.ipc.HamaRPCProtocolVersion;

public interface LyraMessageManager extends
    HamaRPCProtocolVersion {

  public static final String MAX_CACHED_CONNECTIONS_KEY = "hama.messenger.max.cached.connections";
  
  public void init(Configuration conf);
  
  public void init(Configuration conf, int numberThreads, int threadID, int numberServers);
  
  public void init(Configuration conf, int handler);
  
  public void close();

  public void register(AbstractVertex<?, ?, ?>[] replicas, AbstractGlobalState stat);
    
  public void prepare();
  
  public int size();
  
  // RPC stub
  public void syncStat(String peerName, MapWritable stat)
      throws IOException;
  
  public void syncVertex(String peerName, LyraSyncBundle bundle)
      throws IOException;
  
  public void completeMirror(String peerName, LyraMessageBundle<LyraMirrorMessage> bundle)
      throws IOException;

  
  
  public void doSyncStat(MapWritable stat) throws IOException;
  
  public void doSyncVertex(LyraSyncBundle messages) throws IOException;
  
  public void doCompleteMirror(LyraMessageBundle<LyraMirrorMessage> bundle)
      throws IOException;
    
  @SuppressWarnings("rawtypes") 
  public void doTransfer(LyraRecoverMessageBundle bundle, IntWritable from) throws IOException;
  
  public List<LyraRecoverMessage> getRecoverMessageBundle();

  void setMyIdx(int myIdx);
}
