/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp.message;

import java.lang.reflect.Array;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.util.ReflectionUtils;

public class LyraRecoverSenderFactory {
  public static final String LYRA_RECOVER_SENDER_CLASS = "hama.lyra.recover.sender.class";

  /**
   * Returns a messenger via reflection based on what was configured.
   * 
   * @param conf
   * @return
   */
  public static LyraRecoverSender getRecoverSender(
      Configuration conf) throws ClassNotFoundException {
    return (LyraRecoverSender) ReflectionUtils.newInstance(conf
        .getClassByName(conf.get(LYRA_RECOVER_SENDER_CLASS,
            org.apache.hama.bsp.message.LyraRecoverSenderImpl.class
                .getCanonicalName())), conf);
  }
  

  public static LyraRecoverSender[] getRecoverSender(
      Configuration conf, int numberSender) throws ClassNotFoundException {
    LyraRecoverSender[] senders = (LyraRecoverSender[]) Array.newInstance(
        conf.getClassByName(conf.get(LYRA_RECOVER_SENDER_CLASS,
            org.apache.hama.bsp.message.LyraRecoverSenderImpl.class
                .getCanonicalName())), numberSender);
    for (int i = 0; i < numberSender; i++)
      senders[i] = LyraRecoverSenderFactory.getRecoverSender(conf);
    
    return senders;
  }

}
