/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp.sync;

import org.apache.hama.HamaConfiguration;
import org.apache.hama.bsp.BSPJobID;
import org.apache.hama.bsp.TaskAttemptID;

/**
 * MasterSyncClient defines the behavior that BSPMaster should follow
 * to perform different required globally synchronized state changes. 
 *
 */
public interface MasterSyncClient extends SyncClient{

  /**
   * Initialize the Synchronization client.
   * 
   * @param conf The configuration parameters to initialize the client.
   */
  public void init(HamaConfiguration conf);
  
  /**
   * Clears all information stored.
   */
  public void clear();
  
  /**
   * Register a newly added job 
   * @param string
   */
  public void registerJob(String string);

  /**
   * Deregister the job from the system.
   * @param string
   */
  public void deregisterJob(String string);


  /**
   * master will fake a barrier operation to let the surviving nodes continue
   * @param jobId
   * @param attemptId
   * @param tasks
   */
  public void fakeBarrierOperation(BSPJobID jobId, TaskAttemptID attemptId, int tasks);

}
