/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.util;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.hadoop.io.Writable;
import org.apache.hadoop.io.WritableFactories;

public class ArrayListWritable implements Writable {
  private Class<? extends Writable> valueClass;
  private List<Writable> list;

  public ArrayListWritable(Class<? extends Writable> valueClass) {
    if (valueClass == null) { 
      throw new IllegalArgumentException("null valueClass"); 
    }    
    this.valueClass = valueClass;
  }
  
  public ArrayListWritable(Class<? extends Writable> valueClass, List<Writable> list) {
    this(valueClass);
    this.list = list;
  }
  
  public Class getValueClass() {
    return valueClass;
  }
  
  public List<Writable> get() {
    return list;
  }
  
  @Override
  public void write(DataOutput out) throws IOException {
    out.writeInt(list.size());                 // write values
    for (int i = 0; i < list.size(); i++) {
      list.get(i).write(out);
    }
  }

  @Override
  public void readFields(DataInput in) throws IOException {
    list = new ArrayList<Writable>(in.readInt());          // construct values
    for (int i = 0; i < list.size(); i++) {
      Writable value = WritableFactories.newInstance(valueClass);
      value.readFields(in);                       // read a value
      list.add(value);                          // store it in values
    }
  }

}
