/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hama.bsp;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.List;

import junit.framework.Assert;

import org.apache.hadoop.io.Text;

public class TestAbstractVertexRuntimeState {
  /*
 public boolean votedToHalt = false; // modified by vertex itself
  
  public boolean awaked = false; // modify by others
  
  public M value = null;
  
  public M msg = null;
  
  //activate state (out-edges)
  public boolean activated = false; // activate vertex or not?
  public boolean activateAllNeighbors = false; // if true, activatedVertices should be empty
  //private List<Writable> activatedVertices = new ArrayList<Writable>(); // the list of vertices to activate
  //private List<Writable> activatedVertices = null; // the list of vertices to activate
  private List<V>[] activateLists = null;
  */
  public static void main(String args[]){
    AbstractVertexRuntimeState.VERTEX_ID_CLASS = Text.class;
    AbstractVertexRuntimeState.VERTEX_VALUE_CLASS = Text.class;
 
    System.out.println("Test1:");
    Assert.assertTrue(test1());
    System.out.println("Test2:");
    Assert.assertTrue(test2());
    System.out.println("Test3:");
    Assert.assertTrue(test3());
    
  }
  public static boolean test1(){
    AbstractVertexRuntimeState<Text,Text> state = new AbstractVertexRuntimeState<Text, Text>(new Text("111"),new Text("222"),0);
    state.activated = false;
    try
    {
       FileOutputStream fileOut =
       new FileOutputStream("/tmp/test-state.ser");
       ObjectOutputStream out = new ObjectOutputStream(fileOut);
       state.write(out);
       out.close();
       fileOut.close();
       System.out.println("Serialized data is saved in /tmp/employee.ser\nValue: " + state.toString());
    }catch(IOException i)
    {
        i.printStackTrace();
        return false;
    }
    
    try
    {
      AbstractVertexRuntimeState<Text, Text> dstate = new AbstractVertexRuntimeState<Text, Text>(new Text("111"),new Text("222"),0);
       FileInputStream fileIn =
       new FileInputStream("/tmp/test-state.ser");
       ObjectInputStream in = new ObjectInputStream(fileIn);
       dstate.readFields(in);
       in.close();
       fileIn.close();
       System.out.println("Deserialized data is saved in /tmp/employee.ser\nValue: " + dstate.toString());
    }catch(IOException i)
    {
        i.printStackTrace();
        return false;
    }
    return true;
  }
  
  public static boolean test2(){
    AbstractVertexRuntimeState<Text, Text> state = new AbstractVertexRuntimeState<Text, Text>(new Text("111"),new Text("222"),0);
    state.msg = new Text("111");
    state.value = new Text("222");
    state.activated = true;
    state.activateAllNeighbors = true;
    try
    {
       FileOutputStream fileOut =
       new FileOutputStream("/tmp/test-state.ser");
       ObjectOutputStream out = new ObjectOutputStream(fileOut);
       state.write(out);
       out.close();
       fileOut.close();
       System.out.println("Serialized data is saved in /tmp/employee.ser\nValue: " + state.toString());
    }catch(IOException i)
    {
        i.printStackTrace();
        return false;
    }
    
    try
    {
      AbstractVertexRuntimeState<Text, Text> dstate = new AbstractVertexRuntimeState<Text, Text>(new Text("111"),new Text("222"),0);
       FileInputStream fileIn =
       new FileInputStream("/tmp/test-state.ser");
       ObjectInputStream in = new ObjectInputStream(fileIn);
       dstate.readFields(in);
       in.close();
       fileIn.close();
       System.out.println("Deserialized data is saved in /tmp/employee.ser\nValue: " + dstate.toString());
    }catch(IOException i)
    {
        i.printStackTrace();
        return false;
    }
    return true;
  }
  
  
  public static boolean test3(){
    AbstractVertexRuntimeState<Text, Text> state = new AbstractVertexRuntimeState<Text, Text>(new Text("111"),new Text("222"),0);
    state.msg = new Text("111");
    state.value = new Text("222");
    state.activated = true;
    state.activateAllNeighbors = false;
    List<Text>[] lists = state.getActivateLists(2);
   
    lists[0].add(new Text("1"));
    lists[0].add(new Text("23"));
    lists[0].add(new Text("321"));
    
    lists[1].add(new Text("9"));
    lists[1].add(new Text("87"));
    lists[1].add(new Text("6"));
    
    try
    {
       FileOutputStream fileOut =
       new FileOutputStream("/tmp/test-state.ser");
       ObjectOutputStream out = new ObjectOutputStream(fileOut);
       state.write(out);
       out.close();
       fileOut.close();
       System.out.println("Serialized data is saved in /tmp/employee.ser\nValue: " + state.toString());
       List<Text>[] ls = state.getActivateLists(2);
       System.out.print("lists[0]: ");
       for (int i = 0; i < ls[0].size(); i++){
         System.out.print(ls[0].get(i) + " ");
       }
       System.out.print("\nlists[1]: ");
       for (int i = 0; i < ls[1].size(); i++){
         System.out.print(ls[1].get(i) + " ");
       }
    }catch(IOException i)
    {
        i.printStackTrace();
        return false;
    }
    
    try
    {
      AbstractVertexRuntimeState<Text, Text> dstate = new AbstractVertexRuntimeState<Text,Text>(new Text("111"),new Text("222"),0);
       FileInputStream fileIn =
       new FileInputStream("/tmp/test-state.ser");
       ObjectInputStream in = new ObjectInputStream(fileIn);
       dstate.readFields(in);
       in.close();
       fileIn.close();
       System.out.println("Deserialized data is saved in /tmp/employee.ser\nValue: " + dstate.toString());
       List<Text>[] ls = dstate.getActivateLists(2);
       System.out.print("lists[0]: ");
       for (int i = 0; i < ls[0].size(); i++){
         System.out.print(ls[0].get(i) + " ");
       }
       System.out.print("\nlists[1]: ");
       for (int i = 0; i < ls[1].size(); i++){
         System.out.print(ls[1].get(i) + " ");
       }
    }catch(IOException i)
    {
        i.printStackTrace();
        return false;
    }
    return true;
  }
  
}
